"""
dlglab - A simple package with a print function
"""

def print():

    Q_text = "Hi Macha what coping and all ? , what man too much cock showing only!! ok I will help you do this \n 1. Write a program to implement XOR gates using Perceptron. (With Python libraries)\n2. Write a program to implement XOR gates using Perceptron. (Without Python libraries)\n3. Design a Deep NN, optimize the network with 2 different optimizers: Stochastic Gradient Descent and Adam Optimizer\n4. Classification of MNIST Dataset using CNN.\n5. Implement Region-Based CNN for object detection.\n6. Implement RNN for handwriting digit recognition.\n7. Implement Bidirectional LSTM for sentiment analysis\n8. Implement Variational Autoencoders for image-denoising.\n"
    print(Q_text)


__version__ = "0.1.0"
__all__ = ["print"]
